==> mysql-workbench-community-8.0.14-src.tar.gz: mysql-workbench-community-8.0.14-src/frontend/mac/components/WBTabView/WBTabView/Sources/CGColorUtilities.mm <==
/*
 * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
 */

#import "CGColorUtilities.h"

CGColorRef WB_CGColorCreateCalibratedRGB(CGFloat red, CGFloat green, CGFloat blue, CGFloat alpha)
{
	NSColor* calibratedNSColor = [NSColor colorWithCalibratedRed: red
                                                         green: green
                                                          blue: blue
                                                         alpha: alpha];
	
	NSColor* deviceColor = [calibratedNSColor colorUsingColorSpaceName: NSCalibratedRGBColorSpace];
	CGFloat colorComponents[4];
	[deviceColor getRed: &colorComponents[0]
                green: &colorComponents[1]
                 blue: &colorComponents[2]
                alpha: &colorComponents[3]];
	
	CGColorSpaceRef cgColorSpace = CGColorSpaceCreateDeviceRGB();
	CGColorRef calibratedCGColor = CGColorCreate(cgColorSpace, colorComponents);
	CGColorSpaceRelease(cgColorSpace);
  
	return calibratedCGColor;
}

==> mysql-workbench-community-8.0.43-src.tar.gz: mysql-workbench-community-8.0.43-src/frontend/mac/components/WBTabView/WBTabView/Sources/CGColorUtilities.mm <==
/*
 * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is designed to work with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have either included with
 * the program or referenced in the documentation.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
 */

#import "CGColorUtilities.h"

CGColorRef WB_CGColorCreateCalibratedRGB(CGFloat red, CGFloat green, CGFloat blue, CGFloat alpha) {
  NSColor* calibratedNSColor = [NSColor colorWithCalibratedRed: red
                                                         green: green
                                                          blue: blue
                                                         alpha: alpha];

  NSColor* deviceColor = [calibratedNSColor colorUsingColorSpace: NSColorSpace.genericRGBColorSpace];
  CGFloat colorComponents[4];
  [deviceColor getRed: &colorComponents[0]
                green: &colorComponents[1]
                 blue: &colorComponents[2]
                alpha: &colorComponents[3]];

  CGColorSpaceRef cgColorSpace = CGColorSpaceCreateDeviceRGB();
  CGColorRef calibratedCGColor = CGColorCreate(cgColorSpace, colorComponents);
  CGColorSpaceRelease(cgColorSpace);
  
  return calibratedCGColor;
}
